@@ -1,3 +1,3 @@
-///
+#[doc = include_str!("readme.md")]
 #[derive(Copy, Clone, Debug)]
 pub struct TailwindBorderWidth {}
