@@ -1,6 +1,6 @@
 use super::*;
 
-///
+#[doc = include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindRingOffsetColor {
     color: TailwindColor,
@@ -26,3 +26,12 @@ impl TailwindInstance for TailwindRingOffsetColor {
         }
     }
 }
+
+impl TailwindRingOffsetColor {
+    pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
+        Ok(Self { color: TailwindColor::parse(input, arbitrary)? })
+    }
+    pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
+        Ok(Self { color: TailwindColor::parse_arbitrary(arbitrary)? })
+    }
+}
