@@ -1,4 +1,5 @@
 use super::*;
+use std::collections::BTreeSet;
 
 #[derive(Copy, Debug, Clone)]
 pub struct FontSize {
@@ -13,4 +14,10 @@ impl FontSize {
         let height = if height < 0.0 { LengthUnit::rem(height) } else { LengthUnit::percent(height) };
         Self { size, height }
     }
+    pub fn get_properties(&self) -> BTreeSet<CssAttribute> {
+        css_attributes! {
+            "font-size" => self.size.get_properties(),
+            "line-height" => self.height.get_properties(),
+        }
+    }
 }
